@@ -7,7 +7,7 @@
 #include "composerviewinterface.h"
 #include "composerviewbase.h"
 #include "snippet/convertsnippetvariablesutil.h"
-#include <KFormat>
+#include <KIO/Global>
 #include <MessageComposer/AttachmentModel>
 using namespace MessageComposer;
 ComposerViewInterface::ComposerViewInterface(ComposerViewBase *composerView)
@@ -82,7 +82,7 @@ MessageComposer::ComposerAttachmentInterface ComposerViewInterface::attachments(
         for (const MessageCore::AttachmentPart::Ptr &attachment : attachments) {
             fileNames.append(attachment->fileName());
             names.append(attachment->name());
-            nameAndSize.append(QStringLiteral("%1 (%2)").arg(attachment->name(), KFormat().formatByteSize(attachment->size())));
+            nameAndSize.append(QStringLiteral("%1 (%2)").arg(attachment->name(), KIO::convertSize(attachment->size())));
         }
         attachmentInterface.setNames(names);
         attachmentInterface.setNamesAndSize(nameAndSize);
