@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -27,9 +27,7 @@ DKIMCheckSignatureJob::DKIMCheckSignatureJob(QObject *parent)
 {
 }
 
-DKIMCheckSignatureJob::~DKIMCheckSignatureJob()
-{
-}
+DKIMCheckSignatureJob::~DKIMCheckSignatureJob() = default;
 
 MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult DKIMCheckSignatureJob::createCheckResult() const
 {
@@ -168,9 +166,7 @@ void DKIMCheckSignatureJob::start()
     }
 
     // compare body hash
-    qDebug(MESSAGEVIEWER_DKIMCHECKER_LOG)
-        << "resultHash " << resultHash << "mDkimInfo.bodyHash()"
-        << mDkimInfo.bodyHash();
+    qDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << "resultHash " << resultHash << "mDkimInfo.bodyHash()" << mDkimInfo.bodyHash();
     if (resultHash != mDkimInfo.bodyHash().toLatin1()) {
         qCWarning(MESSAGEVIEWER_DKIMCHECKER_LOG) << " Corrupted body hash";
         mError = MessageViewer::DKIMCheckSignatureJob::DKIMError::CorruptedBodyHash;
@@ -324,7 +320,8 @@ QString DKIMCheckSignatureJob::headerCanonizationSimple() const
 
     DKIMHeaderParser parser = mHeaderParser;
 
-    for (const QString &header : mDkimInfo.listSignedHeader()) {
+    const auto listSignedHeader{mDkimInfo.listSignedHeader()};
+    for (const QString &header : listSignedHeader) {
         const QString str = parser.headerType(header.toLower());
         if (!str.isEmpty()) {
             if (!headers.isEmpty()) {
@@ -490,7 +487,7 @@ void DKIMCheckSignatureJob::verifyRSASignature()
         deleteLater();
         return;
     } else {
-      qDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << "Success loading public key";
+        qDebug(MESSAGEVIEWER_DKIMCHECKER_LOG) << "Success loading public key";
     }
     QCA::RSAPublicKey rsaPublicKey = publicKey.toRSA();
     // qDebug() << "publicKey.modulus" << rsaPublicKey.n().toString();
