@@ -1,21 +1,7 @@
 /*
-   Copyright 2018 Sandro Knauß <sknauss@kde.org>
+   SPDX-FileCopyrightText: 2018 Sandro Knauß <sknauss@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 #include "grantleeheaderstyletest.h"
 
@@ -27,8 +13,8 @@
 #include <QFile>
 #include <QProcess>
 #include <QRegularExpression>
-#include <QStringList>
 #include <QStandardPaths>
+#include <QStringList>
 #include <QTest>
 
 using namespace MessageViewer;
@@ -37,9 +23,10 @@ QTEST_MAIN(GrantleeHeaderStyleTest)
 
 void testHeaderFile(const HeaderStyle &style, KMime::Message *msg, const QString &name)
 {
-    QString header = QStringLiteral("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n"
-                                    "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n"
-                                    "<body>\n");
+    QString header = QStringLiteral(
+        "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n"
+        "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n"
+        "<body>\n");
     header += style.format(msg) + QStringLiteral("</div>");
     header += QStringLiteral("\n</body>\n</html>\n");
 
@@ -64,20 +51,14 @@ void testHeaderFile(const HeaderStyle &style, KMime::Message *msg, const QString
     }
     // TODO add proper cmake check for xmllint and diff
     {
-        const QStringList args = QStringList()
-                                 << QStringLiteral("--format")
-                                 << QStringLiteral("--encode") << QStringLiteral("UTF8")
-                                 << QStringLiteral("--output") << fName
-                                 << outName;
+        const QStringList args = QStringList() << QStringLiteral("--format") << QStringLiteral("--encode") << QStringLiteral("UTF8")
+                                               << QStringLiteral("--output") << fName << outName;
         QCOMPARE(QProcess::execute(QStringLiteral("xmllint"), args), 0);
     }
 
     {
         // compare to reference file
-        const QStringList args = QStringList()
-                                 << QStringLiteral("-u")
-                                 << fName
-                                 << QStringLiteral(HEADER_DATA_DIR "/") + fName;
+        const QStringList args = QStringList() << QStringLiteral("-u") << fName << QStringLiteral(HEADER_DATA_DIR "/") + fName;
         QProcess proc;
         proc.setProcessChannelMode(QProcess::ForwardedChannels);
         proc.start(QStringLiteral("diff"), args);
@@ -103,7 +84,6 @@ KMime::Message::Ptr readAndParseMail(const QString &mailFile)
 void GrantleeHeaderStyleTest::initTestCase()
 {
     QStandardPaths::setTestModeEnabled(true);
-    qputenv("LC_ALL", "C");
     expectedDataLocation = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
     expectedDataLocation += QStringLiteral("/messageviewer/defaultthemes");
     QDir targetDir(expectedDataLocation);
@@ -143,13 +123,9 @@ void GrantleeHeaderStyleTest::cleanupTestCase()
 
 const GrantleeTheme::Theme defaultTheme(const QString &name = QStringLiteral("5.2"))
 {
-    const QStringList defaultThemePath = QStandardPaths::locateAll(
-        QStandardPaths::GenericDataLocation,
-        QStringLiteral("messageviewer/defaultthemes/"),
-        QStandardPaths::LocateDirectory);
-    return GrantleeTheme::ThemeManager::loadTheme(defaultThemePath.at(0) + QStringLiteral("/")+name,
-                                                  name,
-                                                  QStringLiteral("kmail_default.desktop"));
+    const QStringList defaultThemePath =
+        QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("messageviewer/defaultthemes/"), QStandardPaths::LocateDirectory);
+    return GrantleeTheme::ThemeManager::loadTheme(defaultThemePath.at(0) + QStringLiteral("/") + name, name, QStringLiteral("kmail_default.desktop"));
 }
 
 void GrantleeHeaderStyleTest::testName()
@@ -168,26 +144,34 @@ void GrantleeHeaderStyleTest::testRenderHeaderInvalidTheme()
 {
     auto style = GrantleeHeaderStyle();
     auto aMsg = new KMime::Message();
+    QCOMPARE(style.theme().isValid(), false);
     QCOMPARE(style.format(aMsg), QStringLiteral("Grantlee theme \"\" is not valid."));
+    delete aMsg;
 }
 
 void GrantleeHeaderStyleTest::testRenderHeaderEmpty()
 {
     auto style = GrantleeHeaderStyle();
     auto aMsg = new KMime::Message();
+    MimeTreeParser::NodeHelper nodeHelper;
     style.setTheme(defaultTheme());
+    style.setNodeHelper(&nodeHelper);
 
     testHeaderFile(style, aMsg, QStringLiteral("empty"));
+    delete aMsg;
 }
 
 void GrantleeHeaderStyleTest::testRenderHeaderVCard()
 {
     auto style = GrantleeHeaderStyle();
     auto aMsg = new KMime::Message();
+    MimeTreeParser::NodeHelper nodeHelper;
     style.setTheme(defaultTheme());
+    style.setNodeHelper(&nodeHelper);
     style.setVCardName(QStringLiteral("nofile.vcd"));
 
     testHeaderFile(style, aMsg, QStringLiteral("vcard"));
+    delete aMsg;
 }
 
 void GrantleeHeaderStyleTest::testRenderHeader_data()
@@ -215,4 +199,5 @@ void GrantleeHeaderStyleTest::testRenderHeader()
     style.setTheme(defaultTheme());
 
     testHeaderFile(style, aMsg.data(), mailFileName);
+    aMsg.clear();
 }
