@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,11 +13,9 @@ MessageViewerConfigureSettingsPluginWidget::MessageViewerConfigureSettingsPlugin
 {
 }
 
-MessageViewerConfigureSettingsPluginWidget::~MessageViewerConfigureSettingsPluginWidget()
-{
-}
+MessageViewerConfigureSettingsPluginWidget::~MessageViewerConfigureSettingsPluginWidget() = default;
 
 QString MessageViewerConfigureSettingsPluginWidget::helpAnchor() const
 {
-    return QString();
+    return {};
 }
