@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "templateextracttextfrommail.h"
-#include "templatewebenginepage.h"
 #include "templateparser_debug.h"
+#include "templatewebenginepage.h"
 
 using namespace TemplateParser;
 
@@ -34,9 +34,7 @@ TemplateExtractTextFromMail::TemplateExtractTextFromMail(QObject *parent)
     connect(mPage, &TemplateWebEnginePage::loadFinished, this, &TemplateExtractTextFromMail::slotLoadFinished);
 }
 
-TemplateExtractTextFromMail::~TemplateExtractTextFromMail()
-{
-}
+TemplateExtractTextFromMail::~TemplateExtractTextFromMail() = default;
 
 void TemplateExtractTextFromMail::setHtmlContent(const QString &html)
 {
