@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -27,9 +27,7 @@ DeveloperToolWidget::DeveloperToolWidget(QWidget *parent)
     mWebEngineView->setPage(mEnginePage);
 }
 
-DeveloperToolWidget::~DeveloperToolWidget()
-{
-}
+DeveloperToolWidget::~DeveloperToolWidget() = default;
 
 QWebEnginePage *DeveloperToolWidget::enginePage() const
 {
